@@ -28,9 +28,10 @@ fn backtrace() {
 
     let contract = Contract::from(program.as_ref());
     let contract_root = contract.root();
-    let contract_undefined = contract.id(&salt, &contract_root);
+    let state_root = Contract::default_state_root();
+    let contract_undefined = contract.id(&salt, &contract_root, &state_root);
 
-    let output = Output::contract_created(contract_undefined);
+    let output = Output::contract_created(contract_undefined, state_root);
 
     let bytecode_witness = 0;
     let tx_deploy = Transaction::create(
@@ -42,6 +43,7 @@ fn backtrace() {
         salt,
         vec![],
         vec![],
+        vec![],
         vec![output],
         vec![program],
     );
@@ -69,9 +71,10 @@ fn backtrace() {
 
     let contract = Contract::from(program.as_ref());
     let contract_root = contract.root();
-    let contract_call = contract.id(&salt, &contract_root);
+    let state_root = Contract::default_state_root();
+    let contract_call = contract.id(&salt, &contract_root, &state_root);
 
-    let output = Output::contract_created(contract_call);
+    let output = Output::contract_created(contract_call, state_root);
 
     let bytecode_witness = 0;
     let tx_deploy = Transaction::create(
@@ -83,6 +86,7 @@ fn backtrace() {
         salt,
         vec![],
         vec![],
+        vec![],
         vec![output],
         vec![program],
     );
