@@ -152,7 +152,7 @@ fn output() {
         Output::withdrawal([0xaa; 32].into(), Word::MAX >> 1, [0xbb; 32].into()),
         Output::change([0xaa; 32].into(), Word::MAX >> 1, [0xbb; 32].into()),
         Output::variable([0xaa; 32].into(), Word::MAX >> 1, [0xbb; 32].into()),
-        Output::contract_created([0xaa; 32].into()),
+        Output::contract_created([0xaa; 32].into(), [0xaa; 32].into()),
     ]);
 }
 
@@ -253,17 +253,6 @@ fn transaction() {
             0xba,
             [0xdd; 32].into(),
             vec![[0xce; 32].into()],
-            vec![i.clone()],
-            vec![o.clone()],
-            vec![w.clone()],
-        ),
-        Transaction::create(
-            Word::MAX >> 1,
-            Word::MAX >> 2,
-            Word::MAX >> 3,
-            Word::MAX >> 4,
-            0xba,
-            [0xdd; 32].into(),
             vec![],
             vec![i.clone()],
             vec![o.clone()],
@@ -278,6 +267,7 @@ fn transaction() {
             [0xdd; 32].into(),
             vec![],
             vec![],
+            vec![i.clone()],
             vec![o.clone()],
             vec![w.clone()],
         ),
@@ -291,6 +281,7 @@ fn transaction() {
             vec![],
             vec![],
             vec![],
+            vec![o.clone()],
             vec![w.clone()],
         ),
         Transaction::create(
@@ -304,6 +295,20 @@ fn transaction() {
             vec![],
             vec![],
             vec![],
+            vec![w.clone()],
+        ),
+        Transaction::create(
+            Word::MAX >> 1,
+            Word::MAX >> 2,
+            Word::MAX >> 3,
+            Word::MAX >> 4,
+            0xba,
+            [0xdd; 32].into(),
+            vec![],
+            vec![],
+            vec![],
+            vec![],
+            vec![],
         ),
     ]);
 }
